@@ -1,4 +1,5 @@
-from typing import Any, Dict, Optional
+from collections import defaultdict
+from typing import Any, DefaultDict, Dict, Optional, Set
 
 from pydantic import BaseModel, validator
 
@@ -21,11 +22,14 @@ class BaseLoggerConfig(BaseModel):
     test_logged: bool = False
     inference_logged: bool = False
     exception: str = ""
+    helper_data: Dict[str, Any] = {}
+    input_data_logged: DefaultDict[str, int] = defaultdict(int)
+    logged_input_ids: DefaultDict[str, Set] = defaultdict(set)
 
     class Config:
         validate_assignment = True
 
-    def reset(self) -> None:
+    def reset(self, factory: bool = False) -> None:
         """Reset all class vars"""
         self.__init__()  # type: ignore
 
