@@ -48,6 +48,8 @@ def disable_network_calls(request, monkeypatch):
 
 @pytest.fixture(scope="function")
 def cleanup_after_use() -> Generator:
+    for task_type in list(TaskType):
+        dataquality.get_model_logger(task_type).logger_config.reset()
     try:
         dataquality.get_model_logger().logger_config.reset()
         if os.path.isdir(BaseGalileoLogger.LOG_FILE_DIR):
@@ -82,18 +84,17 @@ def set_test_config(
         for k, v in kwargs.items():
             if k in config.dict():
                 config.__setattr__(k, v)
+        dataquality.get_model_logger().logger_config.reset()
 
     return curry
 
 
 @pytest.fixture()
 def statuses_response() -> Dict[str, List]:
-    return {
-        "statuses": [
-            {"status": "started", "timestamp": "2022-02-20"},
-            {"status": "finished", "timestamp": "2022-02-24"},
-        ]
-    }
+    return [
+        {"job_id": "1", "status": "in_progress", "created_at": "2022-02-20"},
+        {"job_id": "2", "status": "completed", "created_at": "2022-02-24"},
+    ]
 
 
 @pytest.fixture()
